<?php
/*
Name: WP-Tabbity Class
Description: Supports the WP-Tabbity WordPress plugin
*/

class WPTabbity {
	
	/*
	// addTab:				Adds a shortcode tab to the selected group. Also adds the 
	//						tab group to the page in the correct location, if not already there.
	// @vat str $groupid:	Specifies what group the tab belongs to.
	// @var str $groupcls:	The class a group belongs to.
	// @var str $title:		The tab's title.
	// @var str $id:		The tab's id.
	// @var str $class:		The class a tab belongs to.
	// @var str $order:		The order in which the tab displays, or default.
	*/
	public function addTab($groupid, $title, $id, $class, $order, $content) {
		$class = ($class == 'wp-tabbity') ? $class : $class.' wp-tabbity';
		// Create our html elements for this tab:
		$tab['li'] = '<li class="'.$class.'"><a href="#'.$id.'">'.$title.'</a></li>';
		$tab['content']	= '<div id="'.$id.'">'.do_shortcode(trim($content)).'</div>';
		// If we have an $order number, use that. Else, just put the tab at the end of the list:
		if($order != 'default') :
			$this->tabsets[$groupid][$order] = $tab;
		else :
			$this->tabsets[$groupid][] = $tab;
		endif;
	}
	
	
	
	/*
	// addGroup:Adds the group div into the page and inserts tabs
	//				from this->tabsets.
	*/
	public function addGroup($groupid, $groupcls, $grouptitle) {
		// If the groupid exists, cool. If not, print nothing:
		if(isset($this->tabsets[$groupid])) :
			$groupcls = ($groupcls == 'wp-tabbity-group') ? $groupcls : $groupcls.' wp-tabbity-group';
			$output		= ($grouptitle != '') ? '<h2 class="wp-tabbity-title">'.$grouptitle.'</h2>' : '';
			$output		.= '<div id="'.$groupid.'" class="'.$groupcls.'">';
			// Create tab list:
			$output		.= '<ul>';
			foreach($this->tabsets[$groupid] as $key=>$tab) :
				$output .= $tab['li'];
			endforeach;
			$output		.= '</ul>';
			// Create output divs:
			foreach($this->tabsets[$groupid] as $key=>$tab) :
				$output .= $tab['content'];
			endforeach;
			$output		.= '</div>';
			return $output;
		endif;
	}
	
	
	
	/*
	// getDefaults:Sets default options for new tabs
	*/
	private function getDefaults() {
		// Get our options:
		$options = get_option('wp-tabbity');
		$this->groupid		= isset($options['groupid']) ? $options['groupid'] : 'aTabbityGroup';
		$this->groupcls		= isset($options['groupcls']) ? $options['groupcls'] : 'wp-tabbity-group';
		$this->grouptitle	= isset($options['grouptitle']) ? $options['grouptitle'] : '';
		$this->title		= isset($options['title']) ? $options['title'] : 'A Tabbity Tab';
		$this->id			= isset($options['id']) ? $options['id'] : '';
		$this->class		= isset($options['class']) ? $options['class'] : 'wp-tabbity';
		$this->order		= isset($options['order']) ? $options['order'] : 'default';
		$this->style		= isset($options['style']) ? $options['style'] : 'default';
		$this->css			= '/wp-tabbity/styles/'.$this->style.'/style.css';
	}
	
	/*
	// Horribly redundant settings functions:
	*/
	function registerSettings() {
		register_setting( 'wp-tabbity', 'wp-tabbity' );
		add_settings_section('tabbity-defaults', 'Default Settings', array(&$this, 'displayDefaultText'), 'wp-tabbity');
		add_settings_field('groupcls_setting', 'Default Tab Group Class:', array(&$this, 'groupcls_setting_output'), 'wp-tabbity', 'tabbity-defaults');
		add_settings_field('class_setting', 'Default Tab Class:', array(&$this, 'class_setting_output'), 'wp-tabbity', 'tabbity-defaults');
		add_settings_field('style_setting', 'Tab Style:', array(&$this, 'style_setting_output'), 'wp-tabbity', 'tabbity-defaults');
	}
	function displayDefaultText() {
		echo '<p>Set the default values for WP-Tabbity tabs and tab groups.</p>';
	}
	function groupcls_setting_output() {
		$options = get_option('wp-tabbity');
		echo "<input id='groupcls' name='wp-tabbity[groupcls]' size='40' type='text' value='{$options['groupcls']}' />";
	}
	function class_setting_output() {
		$options = get_option('wp-tabbity');
		echo "<input id='groupcls' name='wp-tabbity[class]' size='40' type='text' value='{$options['class']}' />";
	}
	function style_setting_output() {
		$options = get_option('wp-tabbity');
		$themes = $this->getThemes();
		$output = "<select name='wp-tabbity[style]'>";
		foreach($themes as $key=>$value) :
			$output .= "<option value='$value'";
			if($value == $options['style']) : $output.=" selected='selected' "; endif;
			$output .= ">$value</option>";
		endforeach;
		$output .= "</select>";
		echo $output;
	}
	
	/*
	// getThemes:	Returns a list of available theme directories.
	*/
	function getThemes() {
		$return = array();
		$dir	= dirname(__FILE__).'/styles';
		$list	= scandir($dir);
		foreach($list as $key=>$value) :
			if(!stristr('.', $value) && $value != '..') :
				$return[] = $value;
			endif;
		endforeach;
		return $return;
	}
	
	// Housekeeping:
	function __construct() {
		$this->getDefaults();
	}
}

?>